@@ -1,10 +1,10 @@
 package Net::DNS::Domain;
 
 #
-# $Id: Domain.pm 1195 2014-04-29 12:43:50Z willem $
+# $Id: Domain.pm 1222 2014-06-24 12:30:08Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1195 $)[1];
+$VERSION = (qw$LastChangedRevision: 1222 $)[1];
 
 
 =head1 NAME
@@ -59,12 +59,9 @@ use constant LIBIDN => eval {
 } || 0;
 
 
-my ( $ascii, $utf8 );			## perlcc: initialisation deferred until object creation
-
-sub init {
-	$ascii = Encode::find_encoding('ascii') if ASCII;	# Osborn's Law:
-	$utf8  = Encode::find_encoding('utf8')	if UTF8;	# Variables won't; constants aren't.
-}
+# perlcc: eddress of encoding objects must be determined at runtime
+my $ascii = Encode::find_encoding('ascii') if ASCII;		# Osborn's Law:
+my $utf8  = Encode::find_encoding('utf8')  if UTF8;		# Variables won't; constants aren't.
 
 
 =head1 METHODS
@@ -96,7 +93,6 @@ for zone files described in RFC1035.
 
 use vars qw($ORIGIN);
 my ( $cache1, $cache2, $limit ) = ( {}, {}, 100 );
-my $init;
 
 sub new {
 	my ( $class, $s ) = @_;
@@ -108,8 +104,6 @@ sub new {
 
 	( $cache1, $cache2, $limit ) = ( {}, $cache1, 500 ) unless $limit--;	# recycle cache
 
-	init( $init++ ) unless defined $init;			# initialise encoding object
-
 	my $self = bless {}, $class;
 
 	$s =~ s/\\\\/\\092/g;					# disguise escaped escape
