@@ -1,10 +1,10 @@
 package Net::DNS::Text;
 
 #
-# $Id: Text.pm 1183 2014-04-03 09:08:55Z willem $
+# $Id: Text.pm 1224 2014-07-01 07:57:42Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1183 $)[1];
+$VERSION = (qw$LastChangedRevision: 1224 $)[1];
 
 
 =head1 NAME
@@ -53,12 +53,9 @@ use constant UTF8 => eval {
 } || 0;
 
 
-my ( $ascii, $utf8 );			## perlcc: initialisation deferred until object creation
-
-sub init {
-	$ascii = Encode::find_encoding('ascii') if ASCII;	# Osborn's Law:
-	$utf8  = Encode::find_encoding('utf8')	if UTF8;	# Variables won't; constants aren't.
-}
+# perlcc: eddress of encoding objects must be determined at runtime
+my $ascii = Encode::find_encoding('ascii') if ASCII;		# Osborn's Law:
+my $utf8  = Encode::find_encoding('utf8')  if UTF8;		# Variables won't; constants aren't.
 
 
 =head1 METHODS
@@ -80,14 +77,11 @@ interpretation.
 =cut
 
 my %unescape;				## precalculated numeric escape table
-my $init;
 
 sub new {
 	my $self = bless [], shift;
 	croak 'argument undefined' unless defined $_[0];
 
-	init( $init++ ) unless defined $init;			# encoding object initialisation
-
 	local $_ = &_encode_utf8;
 
 	s/^\042(.*)\042$/$1/;					# strip paired quotes
@@ -131,8 +125,6 @@ sub decode {
 	my $buffer = shift;					# reference to data buffer
 	my $offset = shift || 0;				# offset within buffer
 
-	init( $init++ ) unless defined $init;			# encoding object initialisation
-
 	my $size = unpack "\@$offset C", $$buffer;
 	my $next = ++$offset + $size;
 	croak 'corrupt wire-format data' if $next > length $$buffer;
@@ -188,8 +180,7 @@ sub string {
 	my @s = map split( '', $_ ), @$self;			# escape non-printable
 	my $string = _decode_utf8( join '', map $escape{$_}, @s );
 
-	# Note: Script-specific rules determine which Unicode characters match \s
-	return $string unless $string =~ /^$|\s|["\$'();@]/;	# unquoted contiguous
+	return $string unless $string =~ /^$|[ \t\n\$"();@]/;	# unquoted contiguous
 
 	join '', '"', $string, '"';				# quoted string
 }
